joinedAt property
The timestamp of when this member joined the channel, in seconds. @since 4.10.0
Implementation
@JsonKey(name: 'joined_ts')
int? joinedAt;
The timestamp of when this member joined the channel, in seconds. @since 4.10.0
@JsonKey(name: 'joined_ts')
int? joinedAt;